@@ -30,7 +30,7 @@
 #ifdef COMPILE_USE_QT4
 	#include "kvi_tal_filedialog_qt4.h"
 #else
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		#include "kvi_tal_filedialog_kde.h"
 	#else
 		#include "kvi_tal_filedialog_qt.h"
