@@ -230,7 +230,7 @@ void KviApp::setup()
 	getGlobalKvircDirectory(szPluginsDir,None,"qt-plugins/");
 	setLibraryPaths(TQStringList(szPluginsDir));
 	//KviMessageBox::information(libraryPaths().join(";"));
-	//debug("%1",loader.isLoaded());
+	//tqDebug("%1",loader.isLoaded());
 #endif
 #endif
 
@@ -686,7 +686,7 @@ TQTextCodec * KviApp::defaultTextCodec()
 	c = TQTextCodec::codecForLocale();
 	if(c)return c;
 	c = KviLocale::codecForName("UTF-8");
-	if(!c)debug("KviApp::defaultTextCodec(): cannot find a suitable text codec for locale :/");
+	if(!c)tqDebug("KviApp::defaultTextCodec(): cannot find a suitable text codec for locale :/");
 	return c;
 }
 
@@ -715,14 +715,14 @@ void KviApp::contextSensitiveHelp()
 	}
 	// no way
 	// FIXME: just show up simple plain online help
-	//debug("No way: found no focus widget for that...");
+	//tqDebug("No way: found no focus widget for that...");
 #endif
 }
 
 
 void KviApp::collectGarbage(TQObject * garbage)
 {
-//	if(!g_pGarbageCollector)debug("Ops... no garbage collector ?");
+//	if(!g_pGarbageCollector)tqDebug("Ops... no garbage collector ?");
 	g_pGarbageCollector->collect(garbage);
 }
 
@@ -951,7 +951,7 @@ void KviApp::setClipboardText(const TQString &str)
 
 void KviApp::setClipboardText(const KviStr &str)
 {
-	debug("WARNING : KviApp::setClipboardText(const KviStr &) is deprecated!");
+	tqDebug("WARNING : KviApp::setClipboardText(const KviStr &) is deprecated!");
 	setClipboardText(TQString(str.ptr()));
 }
 
@@ -1143,11 +1143,11 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 
 			if(!g_pKdeDesktopBackground->loadFromShared(TQString("DESKTOP%1").arg(rinfo.currentDesktop())))
 			{
-				debug("Can't load the KDE root background image...");
+				tqDebug("Can't load the KDE root background image...");
 				delete g_pKdeDesktopBackground;
 				g_pKdeDesktopBackground = 0;
 			} //else {
-				// debug("Root pixmap downalod initiated");
+				// tqDebug("Root pixmap downalod initiated");
 			//}
 		}
 
@@ -1303,7 +1303,7 @@ void KviApp::kdeRootPixmapDownloadComplete(bool bSuccess)
 	#ifdef COMPILE_TDE_SUPPORT
 		if(!bSuccess)
 		{
-			debug("Failed to download the KDE root background image...");
+			tqDebug("Failed to download the KDE root background image...");
 		} else {
 			// downloaded!
 			// create shaded copies...
@@ -1582,7 +1582,7 @@ void KviApp::autoConnectToServers()
 
 void KviApp::createFrame()
 {
-	if(g_pFrame)debug("WARNING: Creating the main frame twice!");
+	if(g_pFrame)tqDebug("WARNING: Creating the main frame twice!");
 	g_pFrame = new KviFrame();
 	g_pFrame->createNewConsole(true);
 
