@@ -442,7 +442,7 @@ void KviIrcSocket::connectionEstabilished()
 
 void KviIrcSocket::connectedToProxy()
 {
-	if(!m_pProxy)debug("WARNING: connectedToProxy() without a m_pProxy!");
+	if(!m_pProxy)tqDebug("WARNING: connectedToProxy() without a m_pProxy!");
 
 	// FIXME: Do we want to support SSL proxies ?
 	//        it would be just a matter of SSL handshaking
@@ -647,7 +647,7 @@ void KviIrcSocket::proxyLoginHttp()
 	} else {
 		tmp.append("\r\n");
 	}
-//	debug(tmp.ptr());
+//	tqDebug(tmp.ptr());
 	sendRawData(tmp.ptr(),tmp.len());
 }
 
@@ -702,7 +702,7 @@ void KviIrcSocket::proxyLoginV4()
 	struct in_addr ircInAddr;
 
 	if(!kvi_stringIpToBinaryIp(m_pIrcServer->ip(),&ircInAddr))
-		debug("SOCKET INTERNAL ERROR IN IPV4 (SOCKS4) ADDR CONVERSION");
+		tqDebug("SOCKET INTERNAL ERROR IN IPV4 (SOCKS4) ADDR CONVERSION");
 
 	TQ_UINT32 host=(TQ_UINT32)ircInAddr.s_addr;
 	kvi_memmove((void *)(bufToSend+4),(void *)&host,4);
@@ -914,7 +914,7 @@ void KviIrcSocket::proxySendTargetDataV5()
 #ifdef COMPILE_IPV6_SUPPORT
 		struct in6_addr ircInAddr;
 
-		if(!kvi_stringIpToBinaryIp_V6(m_pIrcServer->ip(),&ircInAddr))debug("SOCKET INTERNAL ERROR IN IPV6 ADDR CONVERSION");
+		if(!kvi_stringIpToBinaryIp_V6(m_pIrcServer->ip(),&ircInAddr))tqDebug("SOCKET INTERNAL ERROR IN IPV6 ADDR CONVERSION");
 		kvi_memmove((void *)(bufToSend + 4),(void *)(&ircInAddr),4);
 		TQ_UINT16 port = (TQ_UINT16)htons(m_pIrcServer->port());
 		kvi_memmove((void *)(bufToSend + 20),(void *)&port,2);
@@ -922,7 +922,7 @@ void KviIrcSocket::proxySendTargetDataV5()
 	} else {
 		struct in_addr ircInAddr;
 
-		if(!kvi_stringIpToBinaryIp(m_pIrcServer->ip(),&ircInAddr))debug("SOCKET INTERNAL ERROR IN IPV4 ADDR CONVERSION");
+		if(!kvi_stringIpToBinaryIp(m_pIrcServer->ip(),&ircInAddr))tqDebug("SOCKET INTERNAL ERROR IN IPV4 ADDR CONVERSION");
 		TQ_UINT32 host = (TQ_UINT32)ircInAddr.s_addr;
 		kvi_memmove((void *)(bufToSend + 4),(void *)&host,4);
 		TQ_UINT16 port = (TQ_UINT16)htons(m_pIrcServer->port());
@@ -1254,7 +1254,7 @@ void KviIrcSocket::doSSLHandshake(int)
 
 	if(!m_pSSL)
 	{
-		debug("Ops... I've lost the SSL class ?");
+		tqDebug("Ops... I've lost the SSL class ?");
 		reset();
 		return; // ops ?
 	}
@@ -1311,7 +1311,7 @@ void KviIrcSocket::doSSLHandshake(int)
 	}
 
 #else  //!COMPILE_SSL_SUPPORT
-	debug("Ops.. ssl handshake without ssl support!...aborting!");
+	tqDebug("Ops.. ssl handshake without ssl support!...aborting!");
 	exit(-1);
 #endif //!COMPILE_SSL_SUPPORT
 }
@@ -1541,7 +1541,7 @@ void KviIrcSocket::processData(char * buffer,int)
 		//The m_pReadBuffer contains at max 1 irc message...
 		//that can not be longer than 510 bytes (the message is not CRLF terminated)
 		// FIXME: Is this limit *really* valid on all servers ?
-		if(m_uReadBufferLen > 510)debug("WARNING : Receiving an invalid irc message from server.");
+		if(m_uReadBufferLen > 510)tqDebug("WARNING : Receiving an invalid irc message from server.");
 	}
 	kvi_free(messageBuffer);
 
