@@ -1019,7 +1019,7 @@ namespace KviTheme
 						cfg.writeEntry(g_pixmapOptionsTable[i].name,szPixName);
 					} else {
 						// we ignore this error for now
-						debug("failed to save %s",szPixPath.utf8().data());
+						tqDebug("failed to save %s",szPixPath.utf8().data());
 						cfg.writeEntry(g_pixmapOptionsTable[i].name,"");
 					}
 				} else {
