@@ -713,7 +713,7 @@ void KviKvsPopupMenu::addExtPopup(const TQString &szItemName,const TQString &szP
 
 void KviKvsPopupMenu::addItemInternal(KviKvsPopupMenuItem * it)
 {
-	if(isLocked())debug("Ooops... KviKvsPopupMenu is locked in ::addItem()");
+	if(isLocked())tqDebug("Ooops... KviKvsPopupMenu is locked in ::addItem()");
 	m_pItemList->append(it);
 }
 
@@ -794,7 +794,7 @@ void KviKvsPopupMenu::setupMenuContents()
 			if(m_bSetupDone)return;
 			// we have been called by doPopup
 			// the menu contents have been already cleared
-			if(m_pTopLevelData)debug("Ops.. something got messed in KviKvsPopupMenu activation system");
+			if(m_pTopLevelData)tqDebug("Ops.. something got messed in KviKvsPopupMenu activation system");
 			// Swap the top level data from temporary to the permanent
 			m_pTopLevelData = m_pTempTopLevelData;
 			m_pTempTopLevelData = 0;
@@ -812,7 +812,7 @@ void KviKvsPopupMenu::setupMenuContents()
 	KviKvsPopupMenuTopLevelData * d = topLevelData();
 	if(!d)
 	{
-		debug("Ops...menu contents changed behind my back!");
+		tqDebug("Ops...menu contents changed behind my back!");
 		return;
 	}
 
@@ -898,9 +898,9 @@ void KviKvsPopupMenu::itemClicked(int itemId)
 				// FIXME: should we print somethng if run() returns false ?
 				lock(false);
 			}
-		} else debug("oops....clicked something that is not an item at position %d",param);
+		} else tqDebug("oops....clicked something that is not an item at position %d",param);
 		// FIXME: #warning "Maybe tell that the window has changed"
-	} else debug("oops....no menu item at position %d",param);
+	} else tqDebug("oops....no menu item at position %d",param);
 	// UGLY TQt 3.0.0.... we can't clear menu contents here :(
 //#if [[[TQT_VERSION IS DEPRECATED]]] < 300
 //	topLevelPopup()->clearMenuContents();
