@@ -47,7 +47,7 @@ void KviKvsTreeNodeExpression::contextDescription(TQString &szBuffer)
 
 void KviKvsTreeNodeExpression::dump(const char * prefix)
 {
-	debug("%s Expression",prefix);
+	tqDebug("%s Expression",prefix);
 }
 
 int KviKvsTreeNodeExpression::precedence()
@@ -57,24 +57,24 @@ int KviKvsTreeNodeExpression::precedence()
 
 KviKvsTreeNodeExpression * KviKvsTreeNodeExpression::left()
 {
-	debug("KviKvsTreeNodeExpression::left() : should never end up here!");
+	tqDebug("KviKvsTreeNodeExpression::left() : should never end up here!");
 	return 0;
 }
 
 KviKvsTreeNodeExpression * KviKvsTreeNodeExpression::right()
 {
-	debug("KviKvsTreeNodeExpression::right() : should never end up here!");
+	tqDebug("KviKvsTreeNodeExpression::right() : should never end up here!");
 	return 0;
 }
 
 void KviKvsTreeNodeExpression::setLeft(KviKvsTreeNodeExpression *)
 {
-	debug("KviKvsTreeNodeExpression::setLeft() : should never end up here!");
+	tqDebug("KviKvsTreeNodeExpression::setLeft() : should never end up here!");
 }
 
 void KviKvsTreeNodeExpression::setRight(KviKvsTreeNodeExpression *)
 {
-	debug("KviKvsTreeNodeExpression::setRight() : should never end up here!");
+	tqDebug("KviKvsTreeNodeExpression::setRight() : should never end up here!");
 }
 
 KviKvsTreeNodeExpression * KviKvsTreeNodeExpression::parentWithPrecedenceLowerThan(int iPrec)
@@ -112,7 +112,7 @@ void KviKvsTreeNodeExpressionVariableOperand::contextDescription(TQString &szBuf
 
 void KviKvsTreeNodeExpressionVariableOperand::dump(const char * prefix)
 {
-	debug("%s ExpressionVariableOperand",prefix);
+	tqDebug("%s ExpressionVariableOperand",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pData->dump(tmp.utf8().data());
@@ -152,7 +152,7 @@ void KviKvsTreeNodeExpressionConstantOperand::contextDescription(TQString &szBuf
 void KviKvsTreeNodeExpressionConstantOperand::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionConstantOperand",prefix);
+	tqDebug("%s ExpressionConstantOperand",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pConstant->dump(tmp.utf8().data());
@@ -190,7 +190,7 @@ void KviKvsTreeNodeExpressionOperator::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeExpressionOperator::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionOperator",prefix);
+	tqDebug("%s ExpressionOperator",prefix);
 #endif
 }
 
@@ -229,7 +229,7 @@ void KviKvsTreeNodeExpressionUnaryOperator::contextDescription(TQString &szBuffe
 void KviKvsTreeNodeExpressionUnaryOperator::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionUnaryOperator",prefix);
+	tqDebug("%s ExpressionUnaryOperator",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pData->dump(tmp.utf8().data());
@@ -275,7 +275,7 @@ void KviKvsTreeNodeExpressionUnaryOperatorNegate::contextDescription(TQString &s
 void KviKvsTreeNodeExpressionUnaryOperatorNegate::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionUnaryOperatorNegate",prefix);
+	tqDebug("%s ExpressionUnaryOperatorNegate",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pData->dump(tmp.utf8().data());
@@ -320,7 +320,7 @@ void KviKvsTreeNodeExpressionUnaryOperatorBitwiseNot::contextDescription(TQStrin
 void KviKvsTreeNodeExpressionUnaryOperatorBitwiseNot::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionUnaryOperatorBitwiseNot",prefix);
+	tqDebug("%s ExpressionUnaryOperatorBitwiseNot",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pData->dump(tmp.utf8().data());
@@ -365,7 +365,7 @@ void KviKvsTreeNodeExpressionUnaryOperatorLogicalNot::contextDescription(TQStrin
 void KviKvsTreeNodeExpressionUnaryOperatorLogicalNot::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s ExpressionUnaryOperatorLogicalNot",prefix);
+	tqDebug("%s ExpressionUnaryOperatorLogicalNot",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pData->dump(tmp.utf8().data());
@@ -470,7 +470,7 @@ void KviKvsTreeNodeExpressionBinaryOperator::contextDescription(TQString &szBuff
 
 void KviKvsTreeNodeExpressionBinaryOperator::dump(const char * prefix)
 {
-	debug("%s ExpressionBinaryOperator",prefix);
+	tqDebug("%s ExpressionBinaryOperator",prefix);
 	dumpOperands(prefix);
 }
 
@@ -481,7 +481,7 @@ void KviKvsTreeNodeExpressionBinaryOperator::dump(const char * prefix)
 	__name::__name(const TQChar * pLocation) \
 	: KviKvsTreeNodeExpressionBinaryOperator(pLocation){} \
 	__name::~__name(){} \
-	void __name::dump(const char * prefix){ debug("%s " __stringname,prefix); dumpOperands(prefix); } \
+	void __name::dump(const char * prefix){ tqDebug("%s " __stringname,prefix); dumpOperands(prefix); } \
 	void __name::contextDescription(TQString &szBuffer){ szBuffer = __contextdescription; } \
 	int __name::precedence(){ return __precedence; };
 
