@@ -267,7 +267,7 @@ void KviFrame::saveModuleExtensionToolBars()
 		s += ":";
 		s += t->descriptor()->name().ptr();
 
-		//debug("FOUND TOOLBAR %s",t->descriptor()->name().ptr());
+		//tqDebug("FOUND TOOLBAR %s",t->descriptor()->name().ptr());
 
 		KVI_OPTION_STRINGLIST(KviOption_stringlistModuleExtensionToolbars).append(s);
 	}
@@ -421,7 +421,7 @@ void KviFrame::accelActivated(int id)
 
 	int keys = (int)(acc->key(id));
 	KviTaskBarItem *item = 0;
-	debug("accel");
+	tqDebug("accel");
 	switch(keys)
 	{
 		case (TQt::Key_Left+TQt::ALT): switchToPrevWindow(); break;
@@ -533,7 +533,7 @@ void KviFrame::saveWindowProperties(KviWindow * wnd,const char * szSection)
 		}
 
 		if(minKey.hasData())g_pWinPropertiesConfig->clearGroup(minKey.ptr());
-		else debug("Oops...no minimum key found!");
+		else tqDebug("Oops...no minimum key found!");
 	}
 
 	// The following line should NOT be needed...but just to be sure...
@@ -1164,7 +1164,7 @@ void KviFrame::toolbarsPopupSelected(int id)
 
 bool KviFrame::focusNextPrevChild(bool next)
 {
-	//debug("FOCUS NEXT PREV CHILD");
+	//tqDebug("FOCUS NEXT PREV CHILD");
 	TQWidget * w = focusWidget();
 	if(w)
 	{
@@ -1227,7 +1227,7 @@ void KviFrame::restoreToolBarPositions()
 	{
 #ifdef COMPILE_USE_QT4
 		if(!restoreState(f.readAll(),1))
-			debug("Error while restoring toolbars position");
+			tqDebug("Error while restoring toolbars position");
 #else //!COMPILE_USE_QT4
 		TQTextStream ts(&f);
 		ts >> *this;
