@@ -274,10 +274,10 @@ void KviInputEditor::dropEvent(TQDropEvent *e)
 	TQStringList list;
 	if(KviUriDrag::decodeLocalFiles(e,list))
 	{
-		//debug("Local files decoded");
+		//tqDebug("Local files decoded");
 		if(!list.isEmpty())
 		{
-			//debug("List not empty");
+			//tqDebug("List not empty");
 			TQStringList::ConstIterator it = list.begin(); //kewl ! :)
     		for( ; it != list.end(); ++it )
 			{
@@ -704,7 +704,7 @@ void KviInputEditor::extractNextBlock(int idx,TQFontMetrics & fm,int curXPos,int
 			}
 			break;
 			default:
-				debug("Ops..");
+				tqDebug("Ops..");
 				exit(0);
 			break;
 		}
@@ -755,7 +755,7 @@ void KviInputEditor::runUpToTheFirstVisibleChar()
 				}
 				break;
 				case 0:
-					debug("KviInputEditor::Encountered invisible end of the string!");
+					tqDebug("KviInputEditor::Encountered invisible end of the string!");
 					exit(0);
 				break;
 			}
@@ -1581,7 +1581,7 @@ void KviInputEditor::keyPressEvent(TQKeyEvent *e)
 			return;
 		}
 
-		//debug("%c",e->ascii());
+		//tqDebug("%c",e->ascii());
 		if(!m_bReadOnly) {
 			insertText(e->text());
 		}
@@ -1759,7 +1759,7 @@ void KviInputEditor::keyReleaseEvent(TQKeyEvent *e)
 			unsigned short ch = m_szAltKeyCode.toUShort(&bOk);
 			if(bOk && ch != 0)
 			{
-				//debug("INSERTING CHAR %d",ch);
+				//tqDebug("INSERTING CHAR %d",ch);
 				insertChar(TQChar(ch));
 				e->accept();
 			}
@@ -2164,7 +2164,7 @@ int KviInputEditor::xPositionFromCharIndex(int chIdx,bool bContentsCoords)
 	// FIXME: this could use fm.width(m_szTextBuffer,chIdx)
 	int curXPos = bContentsCoords ? KVI_INPUT_MARGIN : frameWidth()+KVI_INPUT_MARGIN;
 	int curChar = m_iFirstVisibleChar;
-	//debug("%i",g_pLastFontMetrics);
+	//tqDebug("%i",g_pLastFontMetrics);
 	if(!g_pLastFontMetrics) g_pLastFontMetrics = new TQFontMetrics(KVI_OPTION_FONT(KviOption_fontInput));
 	while(curChar < chIdx)
 	{
@@ -2451,7 +2451,7 @@ void KviInput::inputEditorEnterPressed()
 
 void KviInput::keyPressEvent(TQKeyEvent *e)
 {
-	//debug("KviInput::keyPressEvent(key:%d,state:%d,text:%s)",e->key(),e->state(),e->text().isEmpty() ? "empty" : e->text().utf8().data());
+	//tqDebug("KviInput::keyPressEvent(key:%d,state:%d,text:%s)",e->key(),e->state(),e->text().isEmpty() ? "empty" : e->text().utf8().data());
 
 	if((e->state() & TQt::ControlButton) || (e->state() & TQt::AltButton) || (e->state() & TQt::MetaButton))
 	{
