@@ -126,7 +126,7 @@ bool KviMdiManager::focusNextPrevChild(bool bNext)
 
 void KviMdiManager::drawContents(TQPainter *p,int x,int y,int w,int h)
 {
-	//debug("MY DRAW CONTENTS (%d,%d,%d,%d)",x,y,w,h);
+	//tqDebug("MY DRAW CONTENTS (%d,%d,%d,%d)",x,y,w,h);
 	TQRect r(x,y,w,h);
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -430,7 +430,7 @@ void KviMdiManager::focusTopChild()
 	if(!lpC)return;
 	if(!lpC->isVisible())return;
 	//	if(lpC->state()==KviMdiChild::Minimized)return;
-	//	debug("Focusing top child %s",lpC->name());
+	//	tqDebug("Focusing top child %s",lpC->name());
 	//disable the labels of all the other children
 	for(KviMdiChild *pC=m_pZ->first();pC;pC=m_pZ->next())
 	{
@@ -1008,13 +1008,13 @@ void KviMdiManager::tileAllInternal(int maxWnds,bool bHorizontal)
 	int numToHandle=((numVisible > maxWnds) ? maxWnds : numVisible);
 	int xQuantum=viewport()->width()/pColstable[numToHandle-1];
 	if(xQuantum < ((lpTop->minimumSize().width() > KVI_MDICHILD_MIN_WIDTH) ? lpTop->minimumSize().width() : KVI_MDICHILD_MIN_WIDTH)){
-		if(pColrecall[numToHandle-1]==0)debug("Tile : Not enouh space");
+		if(pColrecall[numToHandle-1]==0)tqDebug("Tile : Not enouh space");
 		else tileAllInternal(pColrecall[numToHandle-1],bHorizontal);
 		return;
 	}
 	int yQuantum=viewport()->height()/pRowstable[numToHandle-1];
 	if(yQuantum < ((lpTop->minimumSize().height() > KVI_MDICHILD_MIN_HEIGHT) ? lpTop->minimumSize().height() : KVI_MDICHILD_MIN_HEIGHT)){
-		if(pRowrecall[numToHandle-1]==0)debug("Tile : Not enough space");
+		if(pRowrecall[numToHandle-1]==0)tqDebug("Tile : Not enough space");
 		else tileAllInternal(pRowrecall[numToHandle-1],bHorizontal);
 		return;
 	}
