@@ -96,7 +96,7 @@ KviMenuBar::~KviMenuBar()
 void KviMenuBar::showEvent(TQShowEvent *e)
 {
 #ifdef COMPILE_USE_QT4
-	debug("menubar show");
+	tqDebug("menubar show");
 	// force a re-layout of the menubar in TQt4 (see the note in enterSDIMode())
 	// by resetting the corner widget
 	m_pFrm->mdiManager()->relayoutMenuButtons();
