@@ -746,7 +746,7 @@ void KviClassicTaskBar::resizeEvent(TQResizeEvent *e)
 	{
 		int iRows = height()/m_iButtonHeight;
 		if(!iRows) iRows=1;
-		debug("%i %i",height(),iRows);
+		tqDebug("%i %i",height(),iRows);
 		resize(width(),iRows*m_iButtonHeight);
 	}
 #endif
@@ -920,7 +920,7 @@ void KviTreeTaskBarItem::paintCell(TQPainter *painter,const TQColorGroup &cg,int
 			{
 				TQPoint pnt = listView()->viewportToContents(TQPoint(int(painter->worldMatrix().dx()),int(painter->worldMatrix().dy())));
 				//p.drawTiledPixmap(0,0,width,height(),*pix,pnt.x(),pnt.y());
-//				debug("%i %i",pnt.x(),pnt.y());
+//				tqDebug("%i %i",pnt.x(),pnt.y());
 				p.translate(-pnt.x(),-pnt.y());
 				KviPixmapUtils::drawPixmapWithPainter(&p,pix,KVI_OPTION_UINT(KviOption_uintTreeTaskBarPixmapAlign),TQRect(pnt.x(),pnt.y(),width,height()),listView()->width(),listView()->height());
 				p.translate(pnt.x(),pnt.y());
