@@ -580,7 +580,7 @@ void KviAliasEditor::exportSelected()
 void KviAliasEditor::exportSelectionInSinglesFiles(KviPointerList<KviAliasListViewItem> *l)
 {
 	if(!m_szDir.endsWith(TQString(KVI_PATH_SEPARATOR)))m_szDir += KVI_PATH_SEPARATOR;
-	debug ("dir %s",m_szDir.latin1());
+	tqDebug ("dir %s",m_szDir.latin1());
 	if (!l->first())
 	{
 		g_pAliasEditorModule->lock();
@@ -596,7 +596,7 @@ void KviAliasEditor::exportSelectionInSinglesFiles(KviPointerList<KviAliasListVi
 	}
 	
 	if(!m_szDir.endsWith(TQString(KVI_PATH_SEPARATOR)))m_szDir += KVI_PATH_SEPARATOR;
-	debug ("dir changed in %s",m_szDir.latin1());
+	tqDebug ("dir changed in %s",m_szDir.latin1());
 	
 	bool bReplaceAll=false;
 	
@@ -1252,7 +1252,7 @@ void KviAliasEditor::recursiveCommit(KviAliasEditorListViewItem * it)
 	if(it->isAlias())
 	{
 		TQString szName = buildFullItemName(it);
-		//debug("ADDING %s",szName.latin1());
+		//tqDebug("ADDING %s",szName.latin1());
 		// WARNING: On MSVC operator new here is valid ONLY because
 		//          KviKvsScript has a non virtual detructor!
 		KviKvsScript * a = new KviKvsScript(szName,((KviAliasListViewItem *)it)->buffer());
