@@ -377,7 +377,7 @@ void KviDccRecvThread::run()
 			// include the artificial delay if needed
 			if(m_pOpt->iIdleStepLengthInMSec > 0)
 			{
-				debug("LOOP: artificial delay");
+				tqDebug("LOOP: artificial delay");
 				msleep(m_pOpt->iIdleStepLengthInMSec);
 			}
 		} else {
@@ -1665,12 +1665,12 @@ bool KviDccFileTransfer::event(TQEvent *e)
 			}
 			break;
 			default:
-				debug("Invalid event type %d received",((KviThreadEvent *)e)->id());
+				tqDebug("Invalid event type %d received",((KviThreadEvent *)e)->id());
 			break;
 		}
 	}
 //#warning "Remove this!"
-//	if(e->type() == TQEvent::Close)debug("Close event received");
+//	if(e->type() == TQEvent::Close)tqDebug("Close event received");
 	return KviFileTransfer::event(e);
 }
 
