@@ -505,7 +505,7 @@ void KviKvsCallbackFileDialog::done(int code)
 
 	if(code == TQDialog::Accepted)
 	{
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 		if(mode() == KFile::ExistingOnly)
 #else
 		if(mode() == TQFileDialog::ExistingFiles)
