@@ -47,7 +47,7 @@ class KviCompletionBox: public KviTalListBox
 	Q_OBJECT
   
 public:
-	KviCompletionBox(TQWidget * parent);
+	KviCompletionBox(TQWidget * parent = 0);
 	~KviCompletionBox(){};
 	
 	void updateContents(TQString word);
