@@ -53,12 +53,12 @@
 #include <tqfontmetrics.h>
 #include <tqevent.h>
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	#include <kurl.h>
 	#include <krun.h>
 	#include <kuserprofile.h>
 	#include <kmimetype.h>
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 extern KviFileTransferWindow * g_pFileTransferWindow;
 
@@ -317,17 +317,17 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 					tmp += "</nobr><br>";
 				}
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 				tmp += "<nobr>Mime: ";
 				tmp += KMimeType::findByPath(szFile)->name();
 				tmp += "</nobr>";
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 				TQLabel * l = new TQLabel(tmp,m_pLocalFilePopup);
 				l->setFrameStyle(TQFrame::Raised | TQFrame::Panel);
 				m_pLocalFilePopup->insertItem(l);
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 				TQString mimetype = KMimeType::findByPath(szFile)->name();
 				KServiceTypeProfile::OfferList offers = KServiceTypeProfile::offers(mimetype,"Application");
 
@@ -342,7 +342,7 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 				for(KServiceTypeProfile::OfferList::Iterator itOffers = offers.begin();
 	   				itOffers != offers.end(); ++itOffers)
 				{
-					id = m_pOpenFilePopup->insertItem((*itOffers).service()->pixmap(KIcon::Small),(*itOffers).service()->name());
+					id = m_pOpenFilePopup->insertItem((*itOffers).service()->pixmap(TDEIcon::Small),(*itOffers).service()->name());
 					m_pOpenFilePopup->setItemParameter(id,idx);
 					idx++;
 				}
@@ -357,7 +357,7 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,TQT_SLOT(openLocalFileFolder()));
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Terminal at Location","filetransferwindow"),this,TQT_SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 //-| Grifisx & Noldor |-
 #ifdef COMPILE_ON_WINDOWS
@@ -423,7 +423,7 @@ KviFileTransfer * KviFileTransferWindow::selectedTransfer()
 
 void KviFileTransferWindow::openFilePopupActivated(int id)
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	int ip = m_pOpenFilePopup->itemParameter(id);
 	if(ip < 0)return;
 	TQString txt = m_pOpenFilePopup->text(id);
@@ -449,7 +449,7 @@ void KviFileTransferWindow::openFilePopupActivated(int id)
 			break;
 		}
 	}
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviFileTransferWindow::openLocalFileTerminal()
@@ -470,7 +470,7 @@ void KviFileTransferWindow::openLocalFileTerminal()
 	system(tmp.local8Bit().data());
 #else //COMPILE_ON_WINDOWS
 // G&N end
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KviFileTransfer * t = selectedTransfer();
 		if(!t)return;
 		TQString tmp = t->localFileName();
@@ -484,7 +484,7 @@ void KviFileTransferWindow::openLocalFileTerminal()
 		tmp.append("\"");
 
 		KRun::runCommand(tmp);
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 #endif //!COMPILE_ON_WINDOWS
 }
 
@@ -522,7 +522,7 @@ void KviFileTransferWindow::openLocalFile()
 	ShellExecute(0,"open",tmp.local8Bit().data(),NULL,NULL,SW_SHOWNORMAL);  //You have to link the shell32.lib
 #else //!COMPILE_ON_WINDOWS
 // G&N end
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KviFileTransfer * t = selectedTransfer();
 		if(!t)return;
 		TQString tmp = t->localFileName();
@@ -541,7 +541,7 @@ void KviFileTransferWindow::openLocalFile()
 		url.setPath(tmp);
 		lst.append(url);
 		KRun::run(*offer, lst);
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 #endif //!COMPILE_ON_WINDOWS
 }
 
@@ -558,7 +558,7 @@ void KviFileTransferWindow::openLocalFileWith()
 	WinExec(tmp.local8Bit().data(),SW_SHOWNORMAL);
 #else //!COMPILE_ON_WINDOWS
 // G&N end
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KviFileTransfer * t = selectedTransfer();
 		if(!t)return;
 		TQString tmp = t->localFileName();
@@ -569,7 +569,7 @@ void KviFileTransferWindow::openLocalFileWith()
 		url.setPath(tmp);
 		lst.append(url);
 		KRun::displayOpenWithDialog(lst);
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 #endif //!COMPILE_ON_WINDOWS
 }
 
@@ -603,7 +603,7 @@ void KviFileTransferWindow::openLocalFileFolder()
 	WinExec(tmp.local8Bit().data(), SW_MAXIMIZE);
 #else //!COMPILE_ON_WINDOWS
 // G&N end
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KviFileTransfer * t = selectedTransfer();
 		if(!t)return;
 		TQString tmp = t->localFileName();
@@ -622,7 +622,7 @@ void KviFileTransferWindow::openLocalFileFolder()
 		url.setPath(tmp);
 		lst.append(url);
 		KRun::run(*offer, lst);
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 #endif //!COMPILE_ON_WINDOWS
 }
 
