@@ -171,8 +171,8 @@ KviNotifierWindow::KviNotifierWindow()
 	TQDesktopWidget * w = TQApplication::desktop();
 	TQRect r = w->availableGeometry(w->primaryScreen()); //w->screenGeometry(w->primaryScreen());
 	
-	/*debug("r.x(),r.y(): %d,%d",r.x(),r.y());
-	debug("r.width(),r.height(): %d,%d",r.width(),r.height());*/
+	/*tqDebug("r.x(),r.y(): %d,%d",r.x(),r.y());
+	tqDebug("r.width(),r.height(): %d,%d",r.width(),r.height());*/
 
 	m_wndRect.setRect( r.x() + r.width() - (iWidth + SPACING), r.y() + r.height() - (iHeight + SPACING), iWidth, iHeight );
 	
@@ -451,7 +451,7 @@ void KviNotifierWindow::heartbeat()
 			targetOpacity/=100;
 			bIncreasing = targetOpacity>m_dOpacity;
 			m_dOpacity += bIncreasing ? OPACITY_STEP : -(OPACITY_STEP);
-			//debug("%f %f %i %i",m_dOpacity,targetOpacity,bIncreasing,(m_dOpacity >= targetOpacity));
+			//tqDebug("%f %f %i %i",m_dOpacity,targetOpacity,bIncreasing,(m_dOpacity >= targetOpacity));
 			if( (bIncreasing && (m_dOpacity >= targetOpacity) ) ||
 				(!bIncreasing && (m_dOpacity <= targetOpacity) )
 				)
@@ -519,13 +519,13 @@ void KviNotifierWindow::doHide(bool bDoAnimate)
 		if((!bDoAnimate) || (x() != m_pWndBorder->x()) || (y() != m_pWndBorder->y()))
 		{
 
-			//debug ("just hide quickly with notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
+			//tqDebug ("just hide quickly with notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
 			// the user asked to not animate or
 			// the window has been moved and the animation would suck anyway
 			// just hide quickly
 			hideNow();
 		} else {
-			//debug ("starting hide animation notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
+			//tqDebug ("starting hide animation notifier x() %d and notifier y() % - WBorderx() %d and WBordery() %d and bDoanimate %d",x(),y(),m_pWndBorder->x(),m_pWndBorder->y(),bDoAnimate);
 			m_pShowHideTimer = new TQTimer();
 			connect(m_pShowHideTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(heartbeat()));
 			m_dOpacity = 1.0 - OPACITY_STEP;
@@ -779,7 +779,7 @@ void KviNotifierWindow::redrawText()
 void KviNotifierWindow::mouseMoveEvent(TQMouseEvent * e)
 {
 
-	//debug ("move on x,y: %d,%d", e->pos().x(), e->pos().y());
+	//tqDebug ("move on x,y: %d,%d", e->pos().x(), e->pos().y());
 
 	if (!m_bLeftButtonIsPressed) {
 	
@@ -874,9 +874,9 @@ void KviNotifierWindow::mousePressEvent(TQMouseEvent * e)
 	}
 
 	if(m_pWndBorder->captionRect().contains(e->pos())) {
-		//debug ("Clicked on m_pWndBorder->rect()");
+		//tqDebug ("Clicked on m_pWndBorder->rect()");
 		if(m_pWndBorder->closeRect().contains(e->pos()))	{
-			//debug ("\tClicked on m_pWndBorder->closeRect()");
+			//tqDebug ("\tClicked on m_pWndBorder->closeRect()");
 			m_bCloseDown = true;
 			m_pWndBorder->setCloseIcon(WDG_ICON_CLICKED);
 			goto sartelo;
@@ -890,12 +890,12 @@ void KviNotifierWindow::mousePressEvent(TQMouseEvent * e)
 		}
 	}
 
-	//debug ("x,y: %d,%d - width,height: %d,%d", m_pWndBorder->rect().x(),m_pWndBorder->rect().y(),m_pWndBorder->rect().width(),m_pWndBorder->rect().height());
+	//tqDebug ("x,y: %d,%d - width,height: %d,%d", m_pWndBorder->rect().x(),m_pWndBorder->rect().y(),m_pWndBorder->rect().width(),m_pWndBorder->rect().height());
 
 	if (m_pWndBorder->rect().contains(e->pos())) {
 		if(m_pWndTabs->currentTab())
 		{
-			//debug ("Clicked on m_pWndBody->textRect()");
+			//tqDebug ("Clicked on m_pWndBody->textRect()");
 			if(m_pWndBody->rctWriteIcon().contains(e->pos()))
 			{
 				m_pWndBody->setWriteIcon(WDG_ICON_CLICKED);
@@ -950,7 +950,7 @@ void KviNotifierWindow::mouseReleaseEvent(TQMouseEvent * e)
 	if(m_pWndBorder->captionRect().contains(e->pos())) {
 	
 		if(m_pWndBorder->closeRect().contains(e->pos())) {
-			//debug ("hide now from release event");
+			//tqDebug ("hide now from release event");
 			hideNow();
 		} else {
 			update();
