@@ -415,17 +415,17 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 					tmp += "</nobr><br>";
 				}
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 				tmp += "<nobr>Mime: ";
 				tmp += KMimeType::findByPath(szFile)->name();
 				tmp += "</nobr>";
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 				TQLabel * l = new TQLabel(tmp,m_pLocalFilePopup);
 				l->setFrameStyle(TQFrame::Raised | TQFrame::Panel);
 				m_pLocalFilePopup->insertItem(l);
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 				TQString mimetype = KMimeType::findByPath(szFile)->name();
 				KServiceTypeProfile::OfferList offers = KServiceTypeProfile::offers(mimetype,"Application");
 
@@ -437,7 +437,7 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 				for(KServiceTypeProfile::OfferList::Iterator itOffers = offers.begin();
 	   				itOffers != offers.end(); ++itOffers)
 				{
-					id = m_pOpenFilePopup->insertItem((*itOffers).service()->pixmap(KIcon::Small),(*itOffers).service()->name());
+					id = m_pOpenFilePopup->insertItem((*itOffers).service()->pixmap(TDEIcon::Small),(*itOffers).service()->name());
 					m_pOpenFilePopup->setItemParameter(id,idx);
 					idx++;
 				}
@@ -454,7 +454,7 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open folder","filetransferwindow"),this,TQT_SLOT(openLocalFileFolder()));
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Reach in terminal","filetransferwindow"),this,TQT_SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Copy path to clipboard","filetransferwindow"),this,TQT_SLOT(copyLocalFileToClipboard()));
 
 				m_pContextPopup->insertItem(__tr2qs_ctx("Local file","filetransferwindow"),m_pLocalFilePopup);
@@ -498,7 +498,7 @@ KviSharedFiles * KviSharedFilesWindow::selectedTransfer()
 
 void KviSharedFilesWindow::openFilePopupActivated(int id)
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	int ip = m_pOpenFilePopup->itemParameter(id);
 	if(ip < 0)return;
 	TQString txt = m_pOpenFilePopup->text(id);
@@ -524,12 +524,12 @@ void KviSharedFilesWindow::openFilePopupActivated(int id)
 			break;
 		}
 	}
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviSharedFilesWindow::openLocalFileTerminal()
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	KviSharedFiles * t = selectedTransfer();
 	if(!t)return;
 	TQString tmp = t->localFileName();
@@ -543,12 +543,12 @@ void KviSharedFilesWindow::openLocalFileTerminal()
 	tmp.append("\"");
 
 	KRun::runCommand(tmp);
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviSharedFilesWindow::openLocalFile()
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	KviSharedFiles * t = selectedTransfer();
 	if(!t)return;
 	TQString tmp = t->localFileName();
@@ -567,12 +567,12 @@ void KviSharedFilesWindow::openLocalFile()
 	url.setPath(tmp);
 	lst.append(url);
 	KRun::run(*offer, lst);
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviSharedFilesWindow::openLocalFileWith()
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	KviSharedFiles * t = selectedTransfer();
 	if(!t)return;
 	TQString tmp = t->localFileName();
@@ -583,7 +583,7 @@ void KviSharedFilesWindow::openLocalFileWith()
 	url.setPath(tmp);
 	lst.append(url);
 	KRun::displayOpenWithDialog(lst);
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviSharedFilesWindow::copyLocalFileToClipboard()
@@ -600,7 +600,7 @@ void KviSharedFilesWindow::copyLocalFileToClipboard()
 
 void KviSharedFilesWindow::openLocalFileFolder()
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	KviSharedFiles * t = selectedTransfer();
 	if(!t)return;
 	TQString tmp = t->localFileName();
@@ -619,7 +619,7 @@ void KviSharedFilesWindow::openLocalFileFolder()
 	url.setPath(tmp);
 	lst.append(url);
 	KRun::run(*offer, lst);
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 }
 
 void KviSharedFilesWindow::heartbeat()
